@@ -1,7 +1,10 @@
 from aimped import nlp
-from aimped import utils
 from aimped import version
+from aimped import utils
+from aimped import nitro
 from aimped import dataset
 from aimped import models
 from aimped import train
-from aimped import version
+from aimped import test
+from aimped.nlp import pipeline
+from aimped.version import __version__
